@@ -591,34 +591,6 @@ class Conversation:
             )
             raise  # Re-raise to ensure the error is visible to the caller
 
-    def get_init_params(self):
-        data = {
-            "metadata": {
-                "id": self.id,
-                "name": self.name,
-                "system_prompt": self.system_prompt,
-                "time_enabled": self.time_enabled,
-                "autosave": self.autosave,
-                "save_filepath": self.save_filepath,
-                "load_filepath": self.load_filepath,
-                "context_length": self.context_length,
-                "rules": self.rules,
-                "custom_rules_prompt": self.custom_rules_prompt,
-                "user": self.user,
-                "save_as_yaml_on": self.save_as_yaml_on,
-                "save_as_json_bool": self.save_as_json_bool,
-                "token_count": self.token_count,
-                "message_id_on": self.message_id_on,
-                "tokenizer_model_name": self.tokenizer_model_name,
-                "conversations_dir": self.conversations_dir,
-                "export_method": self.export_method,
-                "created_at": self.created_at,
-            },
-            "conversation_history": self.conversation_history,
-        }
-
-        return data
-
     def save_as_yaml(self, force: bool = True):
         """Save the conversation history and metadata to a YAML file.
 
@@ -634,9 +606,6 @@ class Conversation:
                 )
                 return
 
-            # Get the full data including metadata and conversation history
-            data = self.get_init_params()
-
             # Create directory if it doesn't exist
             save_dir = os.path.dirname(self.save_filepath)
             if save_dir:
@@ -645,7 +614,7 @@ class Conversation:
             # Save with proper formatting
             with open(self.save_filepath, "w", encoding="utf-8") as f:
                 yaml.dump(
-                    data,
+                    self.conversation_history,
                     f,
                     indent=4,
                     default_flow_style=False,
