@@ -1,16 +1,14 @@
-import asyncio
 import csv
 import datetime
 import os
 import uuid
-from typing import Dict, List, Union
-
-import aiofiles
-from pydantic import BaseModel, Field
+from typing import List
 
 from swarms.structs.agent import Agent
-from swarms.structs.base_swarm import BaseSwarm
-from swarms.telemetry.main import log_agent_data
+from swarms.structs.multi_agent_exec import (
+    run_agents_with_different_tasks,
+)
+from swarms.structs.omni_agent_types import AgentType
 from swarms.utils.file_processing import create_file_in_folder
 from swarms.utils.loguru_logger import initialize_logger
 
@@ -25,105 +23,68 @@ formatted_time = datetime.datetime.now().strftime("%Y-%m-%dT%H-%M-%S")
 # --------------- NEW CHANGE END ---------------
 
 
-class AgentConfig(BaseModel):
-    """Configuration for an agent loaded from CSV"""
-
-    agent_name: str
-    description: str
-    system_prompt: str
-    task: str
-
-
-class AgentOutput(BaseModel):
-    agent_name: str
-    task: str
-    result: str
-    timestamp: str
-
-
-class SwarmRunMetadata(BaseModel):
-    run_id: str = Field(
-        default_factory=lambda: f"spreadsheet_swarm_run_{uuid_hex}"
-    )
-    name: str
-    description: str
-    agents: List[str]
-    start_time: str = Field(
-        default_factory=lambda: time,
-        description="The start time of the swarm run.",
-    )
-    end_time: str
-    tasks_completed: int
-    outputs: List[AgentOutput]
-    number_of_agents: int = Field(
-        ...,
-        description="The number of agents participating in the swarm.",
-    )
-
-
-class SpreadSheetSwarm(BaseSwarm):
+class SpreadSheetSwarm:
     """
     A swarm that processes tasks concurrently using multiple agents.
 
     Args:
         name (str, optional): The name of the swarm. Defaults to "Spreadsheet-Swarm".
         description (str, optional): The description of the swarm. Defaults to "A swarm that processes tasks concurrently using multiple agents.".
-        agents (Union[Agent, List[Agent]], optional): The agents participating in the swarm. Defaults to an empty list.
-        autosave_on (bool, optional): Whether to enable autosave of swarm metadata. Defaults to True.
+        agents (Union[Agent, List[Agent], None], optional): The agents participating in the swarm. If None, agents will be loaded from load_path. Defaults to None.
+        autosave (bool, optional): Whether to enable autosave of swarm metadata. Defaults to True.
         save_file_path (str, optional): The file path to save the swarm metadata as a CSV file. Defaults to "spreedsheet_swarm.csv".
         max_loops (int, optional): The number of times to repeat the swarm tasks. Defaults to 1.
         workspace_dir (str, optional): The directory path of the workspace. Defaults to the value of the "WORKSPACE_DIR" environment variable.
+        load_path (str, optional): Path to CSV file containing agent configurations. Required if agents is None.
         *args: Additional positional arguments.
         **kwargs: Additional keyword arguments.
+
+    Note:
+        Either 'agents' or 'load_path' must be provided. If both are provided, 'agents' will be used.
     """
 
     def __init__(
         self,
         name: str = "Spreadsheet-Swarm",
-        description: str = "A swarm that that processes tasks concurrently using multiple agents and saves the metadata to a CSV file.",
-        agents: Union[Agent, List[Agent]] = [],
-        autosave_on: bool = True,
+        description: str = "A swarm that processes tasks concurrently using multiple agents and saves the metadata to a CSV file.",
+        agents: List[AgentType] = None,
+        autosave: bool = True,
         save_file_path: str = None,
         max_loops: int = 1,
         workspace_dir: str = os.getenv("WORKSPACE_DIR"),
         load_path: str = None,
+        verbose: bool = False,
         *args,
         **kwargs,
     ):
-        super().__init__(
-            name=name,
-            description=description,
-            agents=agents if isinstance(agents, list) else [agents],
-            *args,
-            **kwargs,
-        )
         self.name = name
         self.description = description
+        self.agents = agents
         self.save_file_path = save_file_path
-        self.autosave_on = autosave_on
+        self.autosave = autosave
         self.max_loops = max_loops
         self.workspace_dir = workspace_dir
         self.load_path = load_path
-        self.agent_configs: Dict[str, AgentConfig] = {}
+        self.verbose = verbose
 
         # --------------- NEW CHANGE START ---------------
         # The save_file_path now uses the formatted_time and uuid_hex
-        self.save_file_path = (
-            f"spreadsheet_swarm_run_id_{uuid_hex}.csv"
-        )
+        # Save CSV files in the workspace_dir instead of root directory
+        if self.workspace_dir:
+            os.makedirs(self.workspace_dir, exist_ok=True)
+            self.save_file_path = os.path.join(
+                self.workspace_dir,
+                f"spreadsheet_swarm_run_id_{uuid_hex}.csv",
+            )
+        else:
+            self.save_file_path = (
+                f"spreadsheet_swarm_run_id_{uuid_hex}.csv"
+            )
         # --------------- NEW CHANGE END ---------------
 
-        self.metadata = SwarmRunMetadata(
-            run_id=f"spreadsheet_swarm_run_{time}",
-            name=name,
-            description=description,
-            agents=[agent.name for agent in agents],
-            start_time=time,
-            end_time="",
-            tasks_completed=0,
-            outputs=[],
-            number_of_agents=len(agents),
-        )
+        self.outputs = []
+        self.tasks_completed = 0
+        self.agent_tasks = {}  # Simple dict to store agent tasks
 
         self.reliability_check()
 
@@ -132,21 +93,28 @@ class SpreadSheetSwarm(BaseSwarm):
         Check the reliability of the swarm.
 
         Raises:
-            ValueError: If no agents are provided or no save file path is provided.
+            ValueError: If neither agents nor load_path is provided, or if max_loops is not provided.
         """
-        logger.info("Checking the reliability of the swarm...")
+        if self.verbose:
+            logger.info(
+                f"SpreadSheetSwarm Name: {self.name} reliability checks in progress..."
+            )
+
+        if not self.agents:
+            raise ValueError("No agents are provided.")
 
-        # if not self.agents:
-        #     raise ValueError("No agents are provided.")
-        # if not self.save_file_path:
-        #     raise ValueError("No save file path is provided.")
         if not self.max_loops:
             raise ValueError("No max loops are provided.")
 
-        logger.info("Swarm reliability check passed.")
-        logger.info("Swarm is ready to run.")
+        if self.verbose:
+            logger.info(
+                f"SpreadSheetSwarm Name: {self.name} reliability check passed."
+            )
+            logger.info(
+                f"SpreadSheetSwarm Name: {self.name} is ready to run."
+            )
 
-    async def _load_from_csv(self):
+    def _load_from_csv(self):
         """
         Load agent configurations from a CSV file.
         Expected CSV format: agent_name,description,system_prompt,task
@@ -160,23 +128,21 @@ class SpreadSheetSwarm(BaseSwarm):
                 f"Loading agent configurations from {csv_path}"
             )
 
-            async with aiofiles.open(csv_path, mode="r") as file:
-                content = await file.read()
-                csv_reader = csv.DictReader(content.splitlines())
+            with open(csv_path, mode="r") as file:
+                csv_reader = csv.DictReader(file)
 
                 for row in csv_reader:
-                    config = AgentConfig(
-                        agent_name=row["agent_name"],
-                        description=row["description"],
-                        system_prompt=row["system_prompt"],
-                        task=row["task"],
-                    )
+                    agent_name = row["agent_name"]
+                    task = row["task"]
+
+                    # Store agent task mapping
+                    self.agent_tasks[agent_name] = task
 
                     # Create new agent with configuration
                     new_agent = Agent(
-                        agent_name=config.agent_name,
-                        system_prompt=config.system_prompt,
-                        description=config.description,
+                        agent_name=agent_name,
+                        system_prompt=row["system_prompt"],
+                        description=row["description"],
                         model_name=(
                             row["model_name"]
                             if "model_name" in row
@@ -194,7 +160,6 @@ class SpreadSheetSwarm(BaseSwarm):
                             if "user_name" in row
                             else "user"
                         ),
-                        # output_type="str",
                         stopping_token=(
                             row["stopping_token"]
                             if "stopping_token" in row
@@ -204,60 +169,68 @@ class SpreadSheetSwarm(BaseSwarm):
 
                     # Add agent to swarm
                     self.agents.append(new_agent)
-                    self.agent_configs[config.agent_name] = config
 
-            # Update metadata with new agents
-            self.metadata.agents = [
-                agent.name for agent in self.agents
-            ]
-            self.metadata.number_of_agents = len(self.agents)
+            # Agents have been loaded successfully
             logger.info(
-                f"Loaded {len(self.agent_configs)} agent configurations"
+                f"Loaded {len(self.agents)} agent configurations"
             )
         except Exception as e:
             logger.error(f"Error loading agent configurations: {e}")
 
     def load_from_csv(self):
-        asyncio.run(self._load_from_csv())
+        self._load_from_csv()
 
-    async def run_from_config(self):
+    def run_from_config(self):
         """
         Run all agents with their configured tasks concurrently
         """
         logger.info("Running agents from configuration")
-        self.metadata.start_time = time
 
-        tasks = []
+        # Load agents from CSV if no agents are provided but load_path is
+        if not self.agents and self.load_path:
+            self.load_from_csv()
+
+        start_time = time
+
+        # Prepare agent-task pairs for concurrent execution
+        agent_task_pairs = []
+
         for agent in self.agents:
-            config = self.agent_configs.get(agent.agent_name)
-            if config:
+            task = self.agent_tasks.get(agent.agent_name)
+            if task:
                 for _ in range(self.max_loops):
-                    tasks.append(
-                        asyncio.to_thread(
-                            self._run_agent_task, agent, config.task
-                        )
-                    )
+                    agent_task_pairs.append((agent, task))
 
-        # Run all tasks concurrently
-        results = await asyncio.gather(*tasks)
+        # Run all tasks concurrently using the multi_agent_exec function
+        results = run_agents_with_different_tasks(agent_task_pairs)
 
         # Process the results
-        for result in results:
-            self._track_output(*result)
+        for i, result in enumerate(results):
+            agent, task = agent_task_pairs[i]
+            self._track_output(agent.agent_name, task, result)
 
-        self.metadata.end_time = time
+        end_time = time
 
-        # Save metadata
-        logger.info("Saving metadata to CSV and JSON...")
-        await self._save_metadata()
+        # Save outputs
+        logger.info("Saving outputs to CSV...")
+        self._save_metadata()
 
-        if self.autosave_on:
+        if self.autosave:
             self.data_to_json_file()
 
-        log_agent_data(self.metadata.model_dump())
-        return self.metadata.model_dump_json(indent=4)
+        # Return simple summary
+        return {
+            "run_id": f"spreadsheet_swarm_run_{uuid_hex}",
+            "name": self.name,
+            "description": self.description,
+            "start_time": start_time,
+            "end_time": end_time,
+            "tasks_completed": self.tasks_completed,
+            "number_of_agents": len(self.agents),
+            "outputs": self.outputs,
+        }
 
-    async def _run(self, task: str = None, *args, **kwargs):
+    def _run(self, task: str = None, *args, **kwargs):
         """
         Run the swarm either with a specific task or using configured tasks.
 
@@ -267,21 +240,34 @@ class SpreadSheetSwarm(BaseSwarm):
             **kwargs: Additional keyword arguments.
 
         Returns:
-            str: The JSON representation of the swarm metadata.
+            dict: Summary of the swarm execution.
         """
-        if task is None and self.agent_configs:
-            return await self.run_from_config()
-        else:
-            self.metadata.start_time = time
-            await self._run_tasks(task, *args, **kwargs)
-            self.metadata.end_time = time
-            await self._save_metadata()
+        # Load agents from CSV if no agents are provided but load_path is
+        if not self.agents and self.load_path:
+            self.load_from_csv()
 
-            if self.autosave_on:
+        if task is None and self.agent_tasks:
+            return self.run_from_config()
+        else:
+            start_time = time
+            self._run_tasks(task, *args, **kwargs)
+            end_time = time
+            self._save_metadata()
+
+            if self.autosave:
                 self.data_to_json_file()
 
-            print(log_agent_data(self.metadata.model_dump()))
-            return self.metadata.model_dump_json(indent=4)
+            # Return simple summary
+            return {
+                "run_id": f"spreadsheet_swarm_run_{uuid_hex}",
+                "name": self.name,
+                "description": self.description,
+                "start_time": start_time,
+                "end_time": end_time,
+                "tasks_completed": self.tasks_completed,
+                "number_of_agents": len(self.agents),
+                "outputs": self.outputs,
+            }
 
     def run(self, task: str = None, *args, **kwargs):
         """
@@ -293,16 +279,16 @@ class SpreadSheetSwarm(BaseSwarm):
             **kwargs: Additional keyword arguments.
 
         Returns:
-            str: The JSON representation of the swarm metadata.
+            dict: Summary of the swarm execution.
 
         """
         try:
-            return asyncio.run(self._run(task, *args, **kwargs))
+            return self._run(task, *args, **kwargs)
         except Exception as e:
             logger.error(f"Error running swarm: {e}")
             raise e
 
-    async def _run_tasks(self, task: str, *args, **kwargs):
+    def _run_tasks(self, task: str, *args, **kwargs):
         """
         Run the swarm tasks concurrently.
 
@@ -311,49 +297,29 @@ class SpreadSheetSwarm(BaseSwarm):
             *args: Additional positional arguments.
             **kwargs: Additional keyword arguments.
         """
-        tasks = []
+        # Load agents from CSV if no agents are provided but load_path is
+        if not self.agents and self.load_path:
+            self.load_from_csv()
+
+        # Prepare agents and tasks for concurrent execution
+        agents_to_run = []
+        tasks_to_run = []
+
         for _ in range(self.max_loops):
             for agent in self.agents:
-                # Use asyncio.to_thread to run the blocking task in a thread pool
-                tasks.append(
-                    asyncio.to_thread(
-                        self._run_agent_task,
-                        agent,
-                        task,
-                        *args,
-                        **kwargs,
-                    )
-                )
+                agents_to_run.append(agent)
+                tasks_to_run.append(task)
 
-        # Run all tasks concurrently
-        results = await asyncio.gather(*tasks)
+        # Run all tasks concurrently using the multi_agent_exec function
+        results = run_agents_with_different_tasks(
+            list(zip(agents_to_run, tasks_to_run))
+        )
 
         # Process the results
-        for result in results:
-            self._track_output(*result)
-
-    def _run_agent_task(self, agent, task, *args, **kwargs):
-        """
-        Run a single agent's task in a separate thread.
-
-        Args:
-            agent: The agent to run the task for.
-            task (str): The task to be executed by the agent.
-            *args: Additional positional arguments.
-            **kwargs: Additional keyword arguments.
-
-        Returns:
-            Tuple[str, str, str]: A tuple containing the agent name, task, and result.
-        """
-        try:
-            result = agent.run(task=task, *args, **kwargs)
-            # Assuming agent.run() is a blocking call
-            return agent.agent_name, task, result
-        except Exception as e:
-            logger.error(
-                f"Error running task for {agent.agent_name}: {e}"
-            )
-            return agent.agent_name, task, str(e)
+        for i, result in enumerate(results):
+            agent = agents_to_run[i]
+            task_str = tasks_to_run[i]
+            self._track_output(agent.agent_name, task_str, result)
 
     def _track_output(self, agent_name: str, task: str, result: str):
         """
@@ -364,24 +330,36 @@ class SpreadSheetSwarm(BaseSwarm):
             task (str): The task that was completed.
             result (str): The result of the completed task.
         """
-        self.metadata.tasks_completed += 1
-        self.metadata.outputs.append(
-            AgentOutput(
-                agent_name=agent_name,
-                task=task,
-                result=result,
-                timestamp=time,
-            )
+        self.tasks_completed += 1
+        self.outputs.append(
+            {
+                "agent_name": agent_name,
+                "task": task,
+                "result": result,
+                "timestamp": time,
+            }
         )
 
     def export_to_json(self):
         """
-        Export the swarm metadata to JSON.
+        Export the swarm outputs to JSON.
 
         Returns:
-            str: The JSON representation of the swarm metadata.
+            str: The JSON representation of the swarm outputs.
         """
-        return self.metadata.model_dump_json(indent=4)
+        import json
+
+        return json.dumps(
+            {
+                "run_id": f"spreadsheet_swarm_run_{uuid_hex}",
+                "name": self.name,
+                "description": self.description,
+                "tasks_completed": self.tasks_completed,
+                "number_of_agents": len(self.agents),
+                "outputs": self.outputs,
+            },
+            indent=4,
+        )
 
     def data_to_json_file(self):
         """
@@ -395,14 +373,14 @@ class SpreadSheetSwarm(BaseSwarm):
             content=out,
         )
 
-    async def _save_metadata(self):
+    def _save_metadata(self):
         """
         Save the swarm metadata to CSV and JSON.
         """
-        if self.autosave_on:
-            await self._save_to_csv()
+        if self.autosave:
+            self._save_to_csv()
 
-    async def _save_to_csv(self):
+    def _save_to_csv(self):
         """
         Save the swarm metadata to a CSV file.
         """
@@ -414,14 +392,12 @@ class SpreadSheetSwarm(BaseSwarm):
         # Check if file exists before opening it
         file_exists = os.path.exists(self.save_file_path)
 
-        async with aiofiles.open(
-            self.save_file_path, mode="a"
-        ) as file:
+        with open(self.save_file_path, mode="a", newline="") as file:
             writer = csv.writer(file)
 
             # Write header if file doesn't exist
             if not file_exists:
-                await writer.writerow(
+                writer.writerow(
                     [
                         "Run ID",
                         "Agent Name",
@@ -431,13 +407,13 @@ class SpreadSheetSwarm(BaseSwarm):
                     ]
                 )
 
-            for output in self.metadata.outputs:
-                await writer.writerow(
+            for output in self.outputs:
+                writer.writerow(
                     [
                         str(run_id),
-                        output.agent_name,
-                        output.task,
-                        output.result,
-                        output.timestamp,
+                        output["agent_name"],
+                        output["task"],
+                        output["result"],
+                        output["timestamp"],
                     ]
                 )
